summaryrefslogtreecommitdiffstats
path: root/microbe/traverser.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
commit87a016680e3677da3993f333561e79eb0cead7d5 (patch)
treecbda2b4df8b8ee0d8d1617e6c75bec1e3ee0ccba /microbe/traverser.h
parent6ce3d1ad09c1096b5ed3db334e02859e45d5c32b (diff)
downloadktechlab-87a016680e3677da3993f333561e79eb0cead7d5.tar.gz
ktechlab-87a016680e3677da3993f333561e79eb0cead7d5.zip
TQt4 port ktechlab
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktechlab@1238801 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'microbe/traverser.h')
-rw-r--r--microbe/traverser.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/microbe/traverser.h b/microbe/traverser.h
index 7593ba7..a0fcd77 100644
--- a/microbe/traverser.h
+++ b/microbe/traverser.h
@@ -45,7 +45,7 @@ public:
/** Returns true if we are on the left branch, false otherwise. */
bool onLeftBranch();
/** Returns the node on the opposite branch of the parent. */
BTreeNode * oppositeNode();
BTreeNode * current() const { return m_current; }
@@ -57,8 +57,8 @@ public:
*/
void descendLeftwardToTerminal();
- /** It might occur in the future that next() does not just move to the parent,
- so use this for moving to parent
+ /** It might occur in the future that next() does not just move to the tqparent,
+ so use this for moving to tqparent
*/
void moveToParent();
@@ -45,7 +45,7 @@ public:
/** Returns true if we are on the left branch, false otherwise. */
bool onLeftBranch();
- /** Returns the node on the opposite branch of the parent. */
+ /** Returns the node on the opposite branch of the tqparent. */
BTreeNode * oppositeNode();
BTreeNode * current() const { return m_current; }